#[non_exhaustive]pub struct Mmap {}Available on crate feature
full only.Trait Implementations
Sourceimpl Mappable for Mmap
impl Mappable for Mmap
Sourcefn virtual_size(&self, frame_count: usize) -> NonZero<usize>
fn virtual_size(&self, frame_count: usize) -> NonZero<usize>
The number of pages required to create a mapping with
frame_count framesSourcefn base_virtual_offset(&self) -> isize
fn base_virtual_offset(&self) -> isize
The number of pages to offset the physical memory into the allocated virtual memory