Mappable

Trait Mappable 

pub trait Mappable {
    // Required methods
    fn virtual_size(&self, frame_count: usize) -> NonZero<usize>;
    fn base_virtual_offset(&self) -> isize;
}
Available on crate feature full only.
Basic operations to decide how to map memory together.

Implementations of this can be used to instantiate a [RawMapping].

Required Methods

fn virtual_size(&self, frame_count: usize) -> NonZero<usize>

The number of pages required to create a mapping with frame_count frames

fn base_virtual_offset(&self) -> isize

The number of pages to offset the physical memory into the allocated virtual memory

Implementations on Foreign Types

Source

impl<T: ?Sized + Mappable> Mappable for Box<T>

Source

fn virtual_size(&self, frame_count: usize) -> NonZero<usize>

Source

fn base_virtual_offset(&self) -> isize

Implementors